@@ -1,7 +1,7 @@
 #include "libcompat.h"
 
 int
-putenv (const char *string CK_ATTRIBUTE_UNUSED);
+putenv (const char *string CK_ATTRIBUTE_UNUSED)
 {
   assert (0);
   return 0;
