@@ -26,6 +26,7 @@ enum ck_msg_type {
   CK_MSG_CTX,
   CK_MSG_FAIL,
   CK_MSG_LOC,
+  CK_MSG_DURATION,
   CK_MSG_LAST
 };
 
@@ -45,6 +46,11 @@ typedef struct FailMsg
   char *msg;
 } FailMsg;
 
+typedef struct DurationMsg
+{
+  int duration;
+} DurationMsg;
+
 typedef union
 {
   CtxMsg  ctx_msg;
@@ -55,11 +61,13 @@ typedef union
 typedef struct RcvMsg
 {
   enum ck_result_ctx lastctx;
+  enum ck_result_ctx failctx;
   char *fixture_file;
   int fixture_line;
   char *test_file;
   int test_line;
   char *msg;
+  int duration;
 } RcvMsg;
 
 void rcvmsg_free (RcvMsg *rmsg);
@@ -71,5 +79,9 @@ int upack (char *buf, CheckMsg *msg, enum ck_msg_type *type);
 void ppack (int fdes, enum ck_msg_type type, CheckMsg *msg);
 RcvMsg *punpack (int fdes);
 
+#ifdef HAVE_PTHREAD
+void ppack_cleanup( void *mutex );
+#endif
+
 
 #endif /*CHECK_PACK_H */
