@@ -81,8 +81,8 @@ static void srunner_fprint_results (FILE *file, SRunner *sr,
   
   resultlst = sr->resultlst;
   
-  for (list_front(resultlst); !list_at_end(resultlst); list_advance(resultlst)) {
-    TestResult *tr = list_val(resultlst);
+  for (check_list_front(resultlst); !check_list_at_end(resultlst); check_list_advance(resultlst)) {
+    TestResult *tr = check_list_val(resultlst);
     tr_fprint (file, tr, print_mode);
   }
   return;
@@ -136,19 +136,19 @@ void tr_fprint (FILE *file, TestResult *tr, enum print_output print_mode)
 void tr_xmlprint (FILE *file, TestResult *tr, enum print_output print_mode CK_ATTRIBUTE_UNUSED)
 {
   char result[10];
-  char *path_name = "";
-  char *file_name = "";
+  char *path_name = (char*)"";
+  char *file_name = (char*)"";
   char *slash = NULL;
 
   switch (tr->rtype) {
   case CK_PASS:
-    strcpy(result, "success");
+    snprintf(result, sizeof(result), "%s", "success");
     break;
   case CK_FAILURE:
-    strcpy(result, "failure");
+    snprintf(result, sizeof(result), "%s", "failure");
     break;
   case CK_ERROR:
-    strcpy(result, "error");
+    snprintf(result, sizeof(result), "%s", "error");
     break;
   case CK_TEST_RESULT_INVALID:
   default:
@@ -179,10 +179,10 @@ void tr_xmlprint (FILE *file, TestResult *tr, enum print_output print_mode CK_AT
           tr->duration < 0 ? 0 : tr->duration % 1000000);
   fprintf(file, "      <description>");
   fprint_xml_esc(file, tr->tcname);
-  fprintf(file,"</description>\n", tr->tcname);
-  fprintf(file, "      <message>", tr->msg);
+  fprintf(file,"</description>\n");
+  fprintf(file, "      <message>");
   fprint_xml_esc(file, tr->msg);
-  fprintf(file,"</message>\n", tr->msg);
+  fprintf(file,"</message>\n");
   fprintf(file, "    </test>\n");
   
   if (slash != NULL) {
