@@ -7,13 +7,13 @@
 
 START_TEST(test_pass)
 {
-  fail_unless (1==1, "Shouldn't see this");
+  ck_assert_msg (1==1, "Shouldn't see this");
 }
 END_TEST
 
 START_TEST(test_fail)
 {
-  fail("Failure");
+  ck_abort_msg("Failure");
 }
 END_TEST
 
@@ -25,7 +25,7 @@ END_TEST
 
 START_TEST(test_pass2)
 {
-  fail_unless (1==1, "Shouldn't see this");
+  ck_assert_msg (1==1, "Shouldn't see this");
 }
 END_TEST
 
