@@ -7,13 +7,13 @@
 
 START_TEST(test_pass)
 {
-  fail_unless (1==1, "Shouldn't see this");
+  ck_assert_msg (1==1, "Shouldn't see this");
 }
 END_TEST
 
 START_TEST(test_fail)
 {
-  fail("Failure");
+  ck_abort_msg("Failure");
 }
 END_TEST
 
@@ -25,13 +25,19 @@ END_TEST
 
 START_TEST(test_pass2)
 {
-  fail_unless (1==1, "Shouldn't see this");
+  ck_assert_msg (1==1, "Shouldn't see this");
 }
 END_TEST
 
 START_TEST(test_loop)
 {
-  fail_unless (_i==1, "Iteration %d failed", _i);
+  ck_assert_msg (_i==1, "Iteration %d failed", _i);
+}
+END_TEST
+
+START_TEST(test_xml_esc_fail_msg)
+{
+  ck_abort_msg("fail \" ' < > & message");
 }
 END_TEST
 
@@ -64,12 +70,29 @@ static Suite *make_s2_suite (void)
   return s;
 }
 
+/* check that XML special characters are properly escaped in XML log file */
+static Suite *make_xml_esc_suite (void)
+{
+  Suite *s;
+  TCase *tc;
+
+  s = suite_create("XML escape \" ' < > & tests");
+  tc = tcase_create ("description \" ' < > &");
+  suite_add_tcase(s, tc);
+
+  tcase_add_test (tc, test_xml_esc_fail_msg);
+
+  return s;
+}
+
 static void run_tests (int printmode)
 {
   SRunner *sr;
 
   sr = srunner_create(make_s1_suite());
   srunner_add_suite(sr, make_s2_suite());
+  srunner_add_suite(sr, make_xml_esc_suite());
+
   srunner_set_xml(sr, "test.log.xml");
   srunner_run_all(sr, printmode);
   srunner_free(sr);
